#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-streams
version:              0.8.9.9
visibility:           public
id:                   http-streams-0.8.9.9-2Mrm1PGGqz8C3NBmPoWcjl
key:                  http-streams-0.8.9.9-2Mrm1PGGqz8C3NBmPoWcjl
license:              BSD-3-Clause
copyright:            © 2012-2023 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-streams/
synopsis:             An HTTP client using io-streams
description:
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    handle the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  e645fe035f9f9d0ac40de173f2043e4a
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-streams
hs-libraries:         HShttp-streams-0.8.9.9-2Mrm1PGGqz8C3NBmPoWcjl
depends:
    HsOpenSSL-0.11.7.9-F18zIBCxm97EVObZ2izmXg
    aeson-2.2.1.0-FEnGzvKMunxDwDFhBeJYHO
    attoparsec-0.14.4-L7yQnQokRKL4IK7J2HszTx
    attoparsec-aeson-2.2.0.0-HG9CMQkMQvnCesXbjt6Tfp base-4.18.2.1
    base64-bytestring-1.2.1.0-1NArAo3cNK0LoUlrXpNy9J
    blaze-builder-0.4.4.1-4hsr4c7kSq49yqSn7bkiqU bytestring-0.11.5.3
    case-insensitive-1.2.1.0-DkQB71KJg2v82iYJB6vXcb directory-1.3.8.5
    filepath-1.4.300.1 http-common-0.8.3.4-30skTP5PKf9FRajPgrPZZG
    io-streams-1.5.2.2-JSSERcb9FuPCDVC86OHZU2 mtl-2.3.1
    network-3.1.4.0-FBOrYujlwbFGyq28bIJ1UR
    network-uri-2.6.4.2-91j990LrivP71ivMfH7l0g
    openssl-streams-1.2.3.0-6rUKc6JavH6LYjxQvUuSKS text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-2pZfUb3hQF1KSawFItMd4V

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

